@@ -57,7 +57,7 @@ pub struct DistributeNftMember<'info> {
 pub fn distribute_for_nft(
     ctx: Context<DistributeNftMember>,
     distribute_for_mint: bool,
-) -> ProgramResult {
+) -> Result<()> {
     let fanout = &mut ctx.accounts.fanout;
     let fanout_info = fanout.to_account_info();
     let membership_voucher = &mut ctx.accounts.membership_voucher;
