@@ -1,4 +1,4 @@
-use crate::error::ErrorCode;
+use crate::error::HydraError;
 use crate::state::Fanout;
 use crate::utils::validation::assert_owned_by;
 use anchor_lang::prelude::*;
@@ -22,20 +22,25 @@ pub struct SignMetadata<'info> {
     )]
     /// CHECK: Checked in Program
     pub holding_account: UncheckedAccount<'info>,
+    #[account(mut)]
     /// CHECK: Checked in Program
     pub metadata: UncheckedAccount<'info>,
+    #[account(address=mpl_token_metadata::id())]
+    /// CHECK: Checked in Program
+    pub token_metadata_program: UncheckedAccount<'info>,
 }
 
-pub fn sign_metadata(ctx: Context<SignMetadata>) -> ProgramResult {
+pub fn sign_metadata(ctx: Context<SignMetadata>) -> Result<()> {
     let metadata = ctx.accounts.metadata.to_account_info();
     let holding_account = &ctx.accounts.holding_account;
     assert_owned_by(&metadata, &mpl_token_metadata::id())?;
-    let meta_data = &metadata.try_borrow_data()?;
+    let meta_data = metadata.try_borrow_data()?;
     if meta_data[0] != mpl_token_metadata::state::Key::MetadataV1 as u8 {
-        return Err(ErrorCode::InvalidMetadata.into());
+        return Err(HydraError::InvalidMetadata.into());
     }
+    drop(meta_data);
     let ix = mpl_token_metadata::instruction::sign_metadata(
-        mpl_token_metadata::id(),
+        ctx.accounts.token_metadata_program.key(),
         metadata.key(),
         holding_account.key(),
     );
@@ -47,5 +52,12 @@ pub fn sign_metadata(ctx: Context<SignMetadata>) -> ProgramResult {
             ctx.accounts.fanout.key().as_ref(),
             &[*ctx.bumps.get("holding_account").unwrap()],
         ]],
-    )
+    ).map_err(|e| {
+        error::Error::ProgramError(ProgramErrorWithOrigin{
+            program_error: e,
+            error_origin: None,
+            compared_values: None
+        })
+    })?;
+    Ok(())
 }
