@@ -1,4 +1,4 @@
-use crate::error::ErrorCode;
+use crate::error::HydraError;
 use crate::state::{Fanout, FanoutMembershipVoucher};
 use crate::utils::validation::assert_distributed;
 use crate::MembershipModel;
@@ -38,7 +38,7 @@ pub struct TransferShares<'info> {
     pub instructions: UncheckedAccount<'info>,
 }
 
-pub fn transfer_shares(ctx: Context<TransferShares>, shares: u64) -> ProgramResult {
+pub fn transfer_shares(ctx: Context<TransferShares>, shares: u64) -> Result<()> {
     let fanout = &mut ctx.accounts.fanout;
     let from_membership_account = &mut ctx.accounts.from_membership_account;
     let to_membership_account = &mut ctx.accounts.to_membership_account;
@@ -48,17 +48,17 @@ pub fn transfer_shares(ctx: Context<TransferShares>, shares: u64) -> ProgramResu
     assert_distributed(prev_ix, member.key, fanout.membership_model)?;
 
     if to_membership_account.key() == from_membership_account.key() {
-        return Err(ErrorCode::TransferNotSupported.into());
+        return Err(HydraError::TransferNotSupported.into());
     }
 
     if from_membership_account.shares < shares {
-        return Err(ErrorCode::InsufficientShares.into());
+        return Err(HydraError::InsufficientShares.into());
     }
 
     if fanout.membership_model != MembershipModel::NFT
         || fanout.membership_model != MembershipModel::Wallet
     {
-        return Err(ErrorCode::TransferNotSupported.into());
+        return Err(HydraError::TransferNotSupported.into());
     }
     from_membership_account.shares -= shares;
     to_membership_account.shares += shares;
