@@ -1,8 +1,8 @@
-use crate::error::{ErrorCode, OrArithError};
+use crate::error::{HydraError, OrArithError};
 use crate::state::{Fanout, FanoutMembershipMintVoucher, FanoutMembershipVoucher, FanoutMint};
 use anchor_lang::prelude::*;
 
-pub fn calculate_inflow_change(total_inflow: u64, last_inflow: u64) -> Result<u64, ProgramError> {
+pub fn calculate_inflow_change(total_inflow: u64, last_inflow: u64) -> Result<u64> {
     let diff: u64 = total_inflow.checked_sub(last_inflow).or_arith_error()?;
     Ok(diff)
 }
@@ -11,7 +11,7 @@ pub fn calculate_dist_amount(
     member_shares: u64,
     inflow_diff: u64,
     total_shares: u64,
-) -> Result<u64, ProgramError> {
+) -> Result<u64> {
     let member_shares = member_shares as u128;
     let total_shares = total_shares as u128;
     let inflow_diff = inflow_diff as u128;
@@ -26,7 +26,7 @@ pub fn calculate_dist_amount(
 pub fn update_fanout_for_add(
     fanout: &mut Account<Fanout>,
     shares: u64,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     let less_shares = fanout
         .total_available_shares
         .checked_sub(shares)
@@ -36,7 +36,7 @@ pub fn update_fanout_for_add(
     if less_shares.ge(&0) {
         Ok(())
     } else {
-        Err(ErrorCode::InsufficientShares.into())
+        Err(HydraError::InsufficientShares.into())
     }
 }
 
@@ -44,7 +44,7 @@ pub fn update_inflow_for_mint(
     fanout: &mut Account<Fanout>,
     fanout_for_mint: &mut FanoutMint,
     current_snapshot: u64,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     let diff = current_snapshot
         .checked_sub(fanout_for_mint.last_snapshot_amount)
         .or_arith_error()?;
@@ -68,7 +68,7 @@ pub fn update_inflow_for_mint(
     Ok(())
 }
 
-pub fn update_inflow(fanout: &mut Fanout, current_snapshot: u64) -> Result<(), ProgramError> {
+pub fn update_inflow(fanout: &mut Fanout, current_snapshot: u64) -> Result<()> {
     let diff = current_snapshot
         .checked_sub(fanout.last_snapshot_amount)
         .or_arith_error()?;
@@ -93,7 +93,7 @@ pub fn update_snapshot(
     fanout: &mut Account<Fanout>,
     fanout_voucher: &mut Account<FanoutMembershipVoucher>,
     distribution_amount: u64,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     fanout_voucher.last_inflow = fanout.total_inflow;
     fanout.last_snapshot_amount = fanout
         .last_snapshot_amount
@@ -106,7 +106,7 @@ pub fn update_snapshot_for_mint(
     fanout_mint: &mut FanoutMint,
     fanout_mint_voucher: &mut FanoutMembershipMintVoucher,
     distribution_amount: u64,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     fanout_mint_voucher.last_inflow = fanout_mint.total_inflow;
     fanout_mint.last_snapshot_amount = fanout_mint
         .last_snapshot_amount
@@ -119,9 +119,9 @@ pub fn current_lamports(
     rent: &Sysvar<Rent>,
     size: usize,
     holding_account_lamports: u64,
-) -> Result<u64, ProgramError> {
+) -> Result<u64> {
     let subtract_size = rent.minimum_balance(size).max(1);
     holding_account_lamports
         .checked_sub(subtract_size)
-        .ok_or(ErrorCode::NumericalOverflow.into())
+        .ok_or(HydraError::NumericalOverflow.into())
 }
