@@ -1,4 +1,4 @@
-use crate::error::ErrorCode;
+use crate::error::HydraError;
 use crate::state::{Fanout, MembershipModel};
 use anchor_lang::prelude::*;
 use anchor_lang::solana_program::instruction::Instruction;
@@ -9,24 +9,24 @@ pub fn assert_derivation(
     program_id: &Pubkey,
     account: &AccountInfo,
     path: &[&[u8]],
-    error: Option<ProgramError>,
-) -> Result<u8, ProgramError> {
+    error: Option<error::Error>,
+) -> Result<u8> {
     let (key, bump) = Pubkey::find_program_address(&path, program_id);
     if key != *account.key {
         if error.is_some() {
             let err = error.unwrap();
             msg!("Derivation {:?}", err);
-            return Err(err);
+            return Err(err.into());
         }
         msg!("DerivedKeyInvalid");
-        return Err(ErrorCode::DerivedKeyInvalid.into());
+        return Err(HydraError::DerivedKeyInvalid.into());
     }
     Ok(bump)
 }
 
-pub fn assert_owned_by(account: &AccountInfo, owner: &Pubkey) -> ProgramResult {
+pub fn assert_owned_by(account: &AccountInfo, owner: &Pubkey) -> Result<()> {
     if account.owner != owner {
-        Err(ErrorCode::IncorrectOwner.into())
+        Err(HydraError::IncorrectOwner.into())
     } else {
         Ok(())
     }
@@ -35,9 +35,9 @@ pub fn assert_owned_by(account: &AccountInfo, owner: &Pubkey) -> ProgramResult {
 pub fn assert_membership_model(
     fanout: &Account<Fanout>,
     model: MembershipModel,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     if fanout.membership_model != model {
-        return Err(ErrorCode::InvalidMembershipModel.into());
+        return Err(HydraError::InvalidMembershipModel.into());
     }
     Ok(())
 }
@@ -46,8 +46,8 @@ pub fn assert_ata(
     account: &AccountInfo,
     target: &Pubkey,
     mint: &Pubkey,
-    err: Option<ProgramError>,
-) -> Result<u8, ProgramError> {
+    err: Option<error::Error>,
+) -> Result<u8> {
     assert_derivation(
         &anchor_spl::associated_token::ID,
         &account.to_account_info(),
@@ -60,9 +60,9 @@ pub fn assert_ata(
     )
 }
 
-pub fn assert_shares_distributed(fanout: &Account<Fanout>) -> Result<(), ProgramError> {
+pub fn assert_shares_distributed(fanout: &Account<Fanout>) -> Result<()> {
     if fanout.total_available_shares != 0 {
-        return Err(ErrorCode::SharesArentAtMax.into());
+        return Err(HydraError::SharesArentAtMax.into());
     }
     Ok(())
 }
@@ -71,18 +71,18 @@ pub fn assert_holding(
     owner: &AccountInfo,
     token_account: &Account<TokenAccount>,
     mint_info: &AccountInfo,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     assert_owned_by(mint_info, &spl_token::id())?;
     let token_account_info = token_account.to_account_info();
     assert_owned_by(&token_account_info, &spl_token::id())?;
     if token_account.owner != *owner.key {
-        return Err(ErrorCode::IncorrectOwner.into());
+        return Err(HydraError::IncorrectOwner.into());
     }
     if token_account.amount < 1 {
-        return Err(ErrorCode::WalletDoesNotOwnMembershipToken.into());
+        return Err(HydraError::WalletDoesNotOwnMembershipToken.into());
     }
     if token_account.mint != mint_info.key() {
-        return Err(ErrorCode::MintDoesNotMatch.into());
+        return Err(HydraError::MintDoesNotMatch.into());
     }
     Ok(())
 }
@@ -91,9 +91,9 @@ pub fn assert_distributed(
     ix: Instruction,
     subject: &Pubkey,
     membership_model: MembershipModel,
-) -> Result<(), ProgramError> {
+) -> Result<()> {
     if ix.program_id != crate::id() {
-        return Err(ErrorCode::MustDistribute.into());
+        return Err(HydraError::MustDistribute.into());
     }
     let instruction_id = match membership_model {
         MembershipModel::Wallet => [252, 168, 167, 66, 40, 201, 182, 163],
@@ -101,10 +101,10 @@ pub fn assert_distributed(
         MembershipModel::Token => [126, 105, 46, 135, 28, 36, 117, 212],
     };
     if instruction_id != ix.data[0..8] {
-        return Err(ErrorCode::MustDistribute.into());
+        return Err(HydraError::MustDistribute.into());
     }
     if subject != &ix.accounts[1].pubkey {
-        return Err(ErrorCode::MustDistribute.into());
+        return Err(HydraError::MustDistribute.into());
     }
     Ok(())
 }
@@ -112,10 +112,10 @@ pub fn assert_distributed(
 pub fn assert_valid_metadata(
     metadata_account: &AccountInfo,
     mint: &AccountInfo,
-) -> Result<Metadata, ProgramError> {
+) -> Result<Metadata> {
     let meta = Metadata::from_account_info(metadata_account)?;
     if meta.mint != *mint.key {
-        return Err(ErrorCode::InvalidMetadata.into());
+        return Err(HydraError::InvalidMetadata.into());
     }
     Ok(meta)
 }
